.. _time_sequential:

time_sequential modules
=======================
The module provides tools constructing time sequential models using nempy.

.. automodule:: nempy.time_sequential
    :autosummary:
    :members: